@@ -26,7 +26,9 @@ fn main() {
             .collect();
         let scheme_files = glob::glob(target_dir.join("*.c").to_str().unwrap()).unwrap();
         if target_arch == "wasm32" {
-            builder.flag("--sysroot=../../wasi-sysroot");
+            let wasi_sdk_path =
+                &std::env::var("WASI_SDK_DIR").expect("missing environment variable: WASI_SDK_DIR");
+            builder.flag(format!("--sysroot={}", wasi_sdk_path).as_str());
         }
         builder
             .include(internals_include_path)
@@ -79,7 +81,9 @@ fn main() {
             .collect();
         let scheme_files = glob::glob(target_dir.join("*.c").to_str().unwrap()).unwrap();
         if target_arch == "wasm32" {
-            builder.flag("--sysroot=../../wasi-sysroot");
+            let wasi_sdk_path =
+                &std::env::var("WASI_SDK_DIR").expect("missing environment variable: WASI_SDK_DIR");
+            builder.flag(format!("--sysroot={}", wasi_sdk_path).as_str());
         }
         builder
             .include(internals_include_path)
@@ -132,7 +136,9 @@ fn main() {
             .collect();
         let scheme_files = glob::glob(target_dir.join("*.c").to_str().unwrap()).unwrap();
         if target_arch == "wasm32" {
-            builder.flag("--sysroot=../../wasi-sysroot");
+            let wasi_sdk_path =
+                &std::env::var("WASI_SDK_DIR").expect("missing environment variable: WASI_SDK_DIR");
+            builder.flag(format!("--sysroot={}", wasi_sdk_path).as_str());
         }
         builder
             .include(internals_include_path)
@@ -185,7 +191,9 @@ fn main() {
             .collect();
         let scheme_files = glob::glob(target_dir.join("*.c").to_str().unwrap()).unwrap();
         if target_arch == "wasm32" {
-            builder.flag("--sysroot=../../wasi-sysroot");
+            let wasi_sdk_path =
+                &std::env::var("WASI_SDK_DIR").expect("missing environment variable: WASI_SDK_DIR");
+            builder.flag(format!("--sysroot={}", wasi_sdk_path).as_str());
         }
         builder
             .include(internals_include_path)
